==> xs2a-impl-4.11-sources.jar: de/adorsys/psd2/xs2a/service/validator/pis/payment/CancelPaymentValidator.java <==
/*
 * Copyright 2018-2019 adorsys GmbH & Co KG
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.adorsys.psd2.xs2a.service.validator.pis.payment;

import de.adorsys.psd2.xs2a.domain.TppMessageInformation;
import de.adorsys.psd2.xs2a.service.RequestProviderService;
import de.adorsys.psd2.xs2a.service.validator.TppUriHeaderValidator;
import de.adorsys.psd2.xs2a.service.validator.ValidationResult;
import de.adorsys.psd2.xs2a.service.validator.pis.AbstractPisValidator;
import org.jetbrains.annotations.NotNull;
import org.springframework.stereotype.Component;

import java.util.Set;

/**
 * Validator to be used for validating cancel payment request according to some business rules
 */
@Component
public class CancelPaymentValidator extends AbstractPisValidator<CancelPaymentPO> {
    private final TppUriHeaderValidator tppUriHeaderValidator;

    public CancelPaymentValidator(RequestProviderService requestProviderService, TppUriHeaderValidator tppUriHeaderValidator) {
        super(requestProviderService);
        this.tppUriHeaderValidator = tppUriHeaderValidator;
    }
    /**
     * Validates cancel payment request by checking whether:
     * <ul>
     * <li>given payment's type and product are valid for the payment</li>
     * </ul>
     *
     * @param paymentObject payment information object
     * @return valid result if the payment is valid, invalid result with appropriate error otherwise
     */
    @Override
    protected ValidationResult executeBusinessValidation(CancelPaymentPO paymentObject) {
        return ValidationResult.valid();
    }

    @Override
    public @NotNull Set<TppMessageInformation> buildWarningMessages(@NotNull CancelPaymentPO cancelPaymentPO) {
        return tppUriHeaderValidator.buildWarningMessages(cancelPaymentPO.getTppRedirectUri());
    }
}

==> xs2a-impl-8.0.1-sources.jar: de/adorsys/psd2/xs2a/service/validator/pis/payment/CancelPaymentValidator.java <==
/*
 * Copyright 2018-2020 adorsys GmbH & Co KG
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package de.adorsys.psd2.xs2a.service.validator.pis.payment;

import de.adorsys.psd2.xs2a.core.domain.TppMessageInformation;
import de.adorsys.psd2.xs2a.service.validator.TppUriHeaderValidator;
import de.adorsys.psd2.xs2a.service.validator.ValidationResult;
import de.adorsys.psd2.xs2a.service.validator.pis.AbstractPisValidator;
import lombok.RequiredArgsConstructor;
import org.jetbrains.annotations.NotNull;
import org.springframework.stereotype.Component;

import java.util.Set;

/**
 * Validator to be used for validating cancel payment request according to some business rules
 */
@Component
@RequiredArgsConstructor
public class CancelPaymentValidator extends AbstractPisValidator<CancelPaymentPO> {
    private final TppUriHeaderValidator tppUriHeaderValidator;

    /**
     * Validates cancel payment request by checking whether:
     * <ul>
     * <li>given payment's type and product are valid for the payment</li>
     * </ul>
     *
     * @param paymentObject payment information object
     * @return valid result if the payment is valid, invalid result with appropriate error otherwise
     */
    @Override
    protected ValidationResult executeBusinessValidation(CancelPaymentPO paymentObject) {
        return ValidationResult.valid();
    }

    @Override
    public @NotNull Set<TppMessageInformation> buildWarningMessages(@NotNull CancelPaymentPO cancelPaymentPO) {
        return tppUriHeaderValidator.buildWarningMessages(cancelPaymentPO.getTppRedirectUri());
    }
}
